# LiveKit Plugins Neuphonic

Agent Framework plugin for voice synthesis with [Neuphonic](https://neuphonic.com) API.

## Installation

```bash
pip install livekit-plugins-neuphonic
```

## Pre-requisites

You'll need an API key from Neuphonic. It can be set as an environment variable: `NEUPHONIC_API_TOKEN`
